import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import HRDutyService from '@/service/hrduty/hrduty-service';
import HRDutyAuthService from '@/authservice/hrduty/hrduty-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import HRDutyUIService from '@/uiservice/hrduty/hrduty-ui-service';

/**
 * 职务数据选择视图视图基类
 *
 * @export
 * @class HRDutyPickupViewBase
 * @extends {PickupViewBase}
 */
export class HRDutyPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupViewBase
     */
    protected appDeName: string = 'hrduty';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupViewBase
     */
    protected appDeKey: string = 'hrdutyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRDutyPickupViewBase
     */
    protected appDeMajor: string = 'hrdutyname';

    /**
     * 实体服务对象
     *
     * @type {HRDutyService}
     * @memberof HRDutyPickupViewBase
     */
    protected appEntityService: HRDutyService = new HRDutyService;

    /**
     * 实体权限服务对象
     *
     * @type HRDutyUIService
     * @memberof HRDutyPickupViewBase
     */
    public appUIService: HRDutyUIService = new HRDutyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRDutyPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRDutyPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hrduty.views.pickupview.caption',
        srfTitle: 'entities.hrduty.views.pickupview.title',
        srfSubTitle: 'entities.hrduty.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRDutyPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'ebcbf493e0a574cf170412456645a3a7';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRDutyPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRDutyPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'hrduty',
            majorPSDEField: 'hrdutyname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDutyPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}