import { Subject } from 'rxjs';
import { OptionViewBase } from '@/studio-core';
import HREducationService from '@/service/hreducation/hreducation-service';
import HREducationAuthService from '@/authservice/hreducation/hreducation-auth-service';
import OptionViewEngine from '@engine/view/option-view-engine';
import HREducationUIService from '@/uiservice/hreducation/hreducation-ui-service';

/**
 * 教育信息视图基类
 *
 * @export
 * @class HREducationOptionViewBase
 * @extends {OptionViewBase}
 */
export class HREducationOptionViewBase extends OptionViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HREducationOptionViewBase
     */
    protected appDeName: string = 'hreducation';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HREducationOptionViewBase
     */
    protected appDeKey: string = 'hreducationid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HREducationOptionViewBase
     */
    protected appDeMajor: string = 'hreducationname';

    /**
     * 实体服务对象
     *
     * @type {HREducationService}
     * @memberof HREducationOptionViewBase
     */
    protected appEntityService: HREducationService = new HREducationService;

    /**
     * 实体权限服务对象
     *
     * @type HREducationUIService
     * @memberof HREducationOptionViewBase
     */
    public appUIService: HREducationUIService = new HREducationUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HREducationOptionViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HREducationOptionViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hreducation.views.optionview.caption',
        srfTitle: 'entities.hreducation.views.optionview.title',
        srfSubTitle: 'entities.hreducation.views.optionview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HREducationOptionViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '8db1cc9344908f2f9e2fb21f3849a539';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HREducationOptionViewBase
     */
    public engine: OptionViewEngine = new OptionViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HREducationOptionViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'hreducation',
            majorPSDEField: 'hreducationname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREducationOptionViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREducationOptionViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREducationOptionViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}