import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'
import { AppService } from '@/studio-core/service/app-service/AppService';

Vue.use(Router);

const appService = new AppService();

const router = new Router({
    routes: [
        {
            path: '/pim/:pim?',
            beforeEnter: async (to: any, from: any, next: any) => {
                const routerParamsName = 'pim';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    params[routerParamsName] = to.params[routerParamsName];
                }
                const url: string = '/appdata';
                await AuthGuard.getInstance().authGuard(url, params, router);
                appService.navHistory.indexMeta = {
                    caption: 'app.views.pim.title',
                    info:'',
                    viewType: 'APPINDEX',
                    parameters: [
                        { pathName: 'pim', parameterName: 'pim' },
                    ],
                    requireAuth: true,
                };
                next();
            },
            meta: {  
                caption: 'app.views.pim.title',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'pim', parameterName: 'pim' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/pim/pim.vue'),
            children: [
                {
                    path: 'hremployees/:hremployee?/hrrewards/:hrreward?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrreward.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrrewards', parameterName: 'hrreward' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrreward-grid-view/hrreward-grid-view.vue'),
                },
                {
                    path: 'hrrewards/:hrreward?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrreward.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrrewards', parameterName: 'hrreward' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrreward-grid-view/hrreward-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrcertificates/:hrcertificate?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrcertificate.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrcertificates', parameterName: 'hrcertificate' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcertificate-edit-view/hrcertificate-edit-view.vue'),
                },
                {
                    path: 'hrcertificates/:hrcertificate?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrcertificate.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrcertificates', parameterName: 'hrcertificate' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcertificate-edit-view/hrcertificate-edit-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_004/:v_004?',
                    meta: {
                        caption: 'entities.hrpost.views.v_004.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_004', parameterName: 'v_004' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-004/hrpost-v-004.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrduty.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-v-001/hrduty-v-001.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-tab-exp-view/hromhierarchy-cat-tab-exp-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrlanguageabilities/:hrlanguageability?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrlanguageability.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrlanguageabilities', parameterName: 'hrlanguageability' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrlanguage-ability-edit-view/hrlanguage-ability-edit-view.vue'),
                },
                {
                    path: 'hrlanguageabilities/:hrlanguageability?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrlanguageability.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlanguageabilities', parameterName: 'hrlanguageability' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrlanguage-ability-edit-view/hrlanguage-ability-edit-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hroperationunit.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-v-001/hroperation-unit-v-001.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hrduty.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-pickup-grid-view/hrduty-pickup-grid-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hroperationunit.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-v-002/hroperation-unit-v-002.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrpostrels/:hrpostrel?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrpostrel.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-v-002/hrpost-rel-v-002.vue'),
                },
                {
                    path: 'hrpostrels/:hrpostrel?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrpostrel.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-v-002/hrpost-rel-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hremployee.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-pickup-grid-view/hremployee-pickup-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrcontracts/:hrcontract?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrcontract.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrcontracts', parameterName: 'hrcontract' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcontract-grid-view/hrcontract-grid-view.vue'),
                },
                {
                    path: 'hrcontracts/:hrcontract?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrcontract.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrcontracts', parameterName: 'hrcontract' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcontract-grid-view/hrcontract-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_006/:v_006?',
                    meta: {
                        caption: 'entities.hrpost.views.v_006.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_006', parameterName: 'v_006' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-006/hrpost-v-006.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrlegal.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-grid-view/hrlegal-grid-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/hromhierarchies/:hromhierarchy?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-tree-exp-view/hromhierarchy-tree-exp-view.vue'),
                },
                {
                    path: 'hromhierarchies/:hromhierarchy?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-tree-exp-view/hromhierarchy-tree-exp-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrlegal.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-v-002/hrlegal-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_003/:v_003?',
                    meta: {
                        caption: 'entities.hremployee.views.v_003.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_003', parameterName: 'v_003' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-003/hremployee-v-003.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hrpost.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-pickup-view/hrpost-pickup-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hrduty.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-tab-exp-view/hrduty-tab-exp-view.vue'),
                },
                {
                    path: 'hrorganizations/:hrorganization?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hrorganization.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorganizations', parameterName: 'hrorganization' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorganization-pickup-grid-view/hrorganization-pickup-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hrpost.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-pickup-grid-view/hrpost-pickup-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyedus/:hrdutyedu?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-v-001/hrduty-edu-v-001.vue'),
                },
                {
                    path: 'hrdutyedus/:hrdutyedu?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-v-001/hrduty-edu-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrarchives/:hrarchives?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrarchives.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrarchives', parameterName: 'hrarchives' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrarchives-grid-view/hrarchives-grid-view.vue'),
                },
                {
                    path: 'hrarchives/:hrarchives?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrarchives.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrarchives', parameterName: 'hrarchives' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrarchives-grid-view/hrarchives-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hremployee.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-001/hremployee-v-001.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-grid-view/hromhierarchy-cat-grid-view.vue'),
                },
                {
                    path: 'hrorganizations/:hrorganization?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorganization.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorganizations', parameterName: 'hrorganization' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorganization-edit-view/hrorganization-edit-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrpostrels/:hrpostrel?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrpostrel.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-v-001/hrpost-rel-v-001.vue'),
                },
                {
                    path: 'hrpostrels/:hrpostrel?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrpostrel.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-v-001/hrpost-rel-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrresearches/:hrresearch?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrresearch.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrresearches', parameterName: 'hrresearch' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrresearch-grid-view/hrresearch-grid-view.vue'),
                },
                {
                    path: 'hrresearches/:hrresearch?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrresearch.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrresearches', parameterName: 'hrresearch' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrresearch-grid-view/hrresearch-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_003/:v_003?',
                    meta: {
                        caption: 'entities.hrpost.views.v_003.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_003', parameterName: 'v_003' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-003/hrpost-v-003.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hremployee.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-grid-view/hremployee-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrduty.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-v-002/hrduty-v-002.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-pickup-grid-view/hromhierarchy-cat-pickup-grid-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-pickup-view/hromhierarchy-cat-pickup-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_005/:v_005?',
                    meta: {
                        caption: 'entities.hrpost.views.v_005.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_005', parameterName: 'v_005' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-005/hrpost-v-005.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrlegal.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-edit-view/hrlegal-edit-view.vue'),
                },
                {
                    path: 'hrorganizations/:hrorganization?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorganization.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorganizations', parameterName: 'hrorganization' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorganization-grid-view/hrorganization-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hrduty.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-pickup-view/hrduty-pickup-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_006/:v_006?',
                    meta: {
                        caption: 'entities.hremployee.views.v_006.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_006', parameterName: 'v_006' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-006/hremployee-v-006.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hremployee.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-002/hremployee-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/editview/:editview?',
                    meta: {
                        caption: 'entities.hremployee.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-edit-view/hremployee-edit-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrpostrels/:hrpostrel?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrpostrel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-edit-view/hrpost-rel-edit-view.vue'),
                },
                {
                    path: 'hrpostrels/:hrpostrel?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrpostrel.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-edit-view/hrpost-rel-edit-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hreducations/:hreducation?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hreducation.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hreducations', parameterName: 'hreducation' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hreducation-grid-view/hreducation-grid-view.vue'),
                },
                {
                    path: 'hreducations/:hreducation?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hreducation.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hreducations', parameterName: 'hreducation' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hreducation-grid-view/hreducation-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrduty.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-grid-view/hrduty-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrpost.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-edit-view/hrpost-edit-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyedus/:hrdutyedu?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-v-002/hrduty-edu-v-002.vue'),
                },
                {
                    path: 'hrdutyedus/:hrdutyedu?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-v-002/hrduty-edu-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hremployee.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-pickup-view/hremployee-pickup-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/editview/:editview?',
                    meta: {
                        caption: 'entities.hroperationunit.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-edit-view/hroperation-unit-edit-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrpost.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-grid-view/hrpost-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrworkrecords/:hrworkrecord?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrworkrecord.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrworkrecords', parameterName: 'hrworkrecord' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrwork-record-edit-view/hrwork-record-edit-view.vue'),
                },
                {
                    path: 'hrworkrecords/:hrworkrecord?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrworkrecord.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrworkrecords', parameterName: 'hrworkrecord' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrwork-record-edit-view/hrwork-record-edit-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_004/:v_004?',
                    meta: {
                        caption: 'entities.hremployee.views.v_004.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_004', parameterName: 'v_004' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-004/hremployee-v-004.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrpost.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-002/hrpost-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/v_005/:v_005?',
                    meta: {
                        caption: 'entities.hremployee.views.v_005.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'v_005', parameterName: 'v_005' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-v-005/hremployee-v-005.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrdistributions/:hrdistribution?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-edit-view/hrdistribution-edit-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrdistributions/:hrdistribution?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-edit-view/hrdistribution-edit-view.vue'),
                },
                {
                    path: 'hrdistributions/:hrdistribution?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-edit-view/hrdistribution-edit-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutycerts/:hrdutycert?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutycert.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-v-002/hrduty-cert-v-002.vue'),
                },
                {
                    path: 'hrdutycerts/:hrdutycert?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutycert.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-v-002/hrduty-cert-v-002.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgcontacts/:hrorgcontact?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-grid-view/hrorg-contact-grid-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgcontacts/:hrorgcontact?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-grid-view/hrorg-contact-grid-view.vue'),
                },
                {
                    path: 'hrorgcontacts/:hrorgcontact?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-grid-view/hrorg-contact-grid-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hroperationunit.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-grid-view/hroperation-unit-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrtrainingrecords/:hrtrainingrecord?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrtrainingrecord.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrtrainingrecords', parameterName: 'hrtrainingrecord' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtraining-record-edit-view/hrtraining-record-edit-view.vue'),
                },
                {
                    path: 'hrtrainingrecords/:hrtrainingrecord?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrtrainingrecord.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrtrainingrecords', parameterName: 'hrtrainingrecord' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtraining-record-edit-view/hrtraining-record-edit-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgaddresses/:hrorgaddress?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-v-001/hrorg-address-v-001.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgaddresses/:hrorgaddress?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-v-001/hrorg-address-v-001.vue'),
                },
                {
                    path: 'hrorgaddresses/:hrorgaddress?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-v-001/hrorg-address-v-001.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgcontacts/:hrorgcontact?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-v-001/hrorg-contact-v-001.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgcontacts/:hrorgcontact?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-v-001/hrorg-contact-v-001.vue'),
                },
                {
                    path: 'hrorgcontacts/:hrorgcontact?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-v-001/hrorg-contact-v-001.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrpost.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-v-001/hrpost-v-001.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/hromhierarchies/:hromhierarchy?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-grid-view/hromhierarchy-grid-view.vue'),
                },
                {
                    path: 'hromhierarchies/:hromhierarchy?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-grid-view/hromhierarchy-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutycerts/:hrdutycert?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutycert.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-grid-view/hrduty-cert-grid-view.vue'),
                },
                {
                    path: 'hrdutycerts/:hrdutycert?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutycert.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-grid-view/hrduty-cert-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyskills/:hrdutyskill?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-v-002/hrduty-skill-v-002.vue'),
                },
                {
                    path: 'hrdutyskills/:hrdutyskill?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-v-002/hrduty-skill-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/treeexpview/:treeexpview?',
                    meta: {
                        caption: 'entities.hremployee.views.treeexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'treeexpview', parameterName: 'treeexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-tree-exp-view/hremployee-tree-exp-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hremployee.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hremployee-tab-exp-view/hremployee-tab-exp-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrcontracts/:hrcontract?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrcontract.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrcontracts', parameterName: 'hrcontract' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcontract-edit-view/hrcontract-edit-view.vue'),
                },
                {
                    path: 'hrcontracts/:hrcontract?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrcontract.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrcontracts', parameterName: 'hrcontract' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcontract-edit-view/hrcontract-edit-view.vue'),
                },
                {
                    path: 'hrorganizations/:hrorganization?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hrorganization.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorganizations', parameterName: 'hrorganization' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorganization-pickup-view/hrorganization-pickup-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyedus/:hrdutyedu?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-grid-view/hrduty-edu-grid-view.vue'),
                },
                {
                    path: 'hrdutyedus/:hrdutyedu?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutyedu.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyedus', parameterName: 'hrdutyedu' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-edu-grid-view/hrduty-edu-grid-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-dashboard-view/hromhierarchy-cat-dashboard-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hroperationunit.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-tab-exp-view/hroperation-unit-tab-exp-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrlanguageabilities/:hrlanguageability?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrlanguageability.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrlanguageabilities', parameterName: 'hrlanguageability' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrlanguage-ability-grid-view/hrlanguage-ability-grid-view.vue'),
                },
                {
                    path: 'hrlanguageabilities/:hrlanguageability?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrlanguageability.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlanguageabilities', parameterName: 'hrlanguageability' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrlanguage-ability-grid-view/hrlanguage-ability-grid-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgaddresses/:hrorgaddress?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-grid-view/hrorg-address-grid-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgaddresses/:hrorgaddress?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-grid-view/hrorg-address-grid-view.vue'),
                },
                {
                    path: 'hrorgaddresses/:hrorgaddress?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-grid-view/hrorg-address-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutycerts/:hrdutycert?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutycert.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-v-001/hrduty-cert-v-001.vue'),
                },
                {
                    path: 'hrdutycerts/:hrdutycert?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutycert.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutycerts', parameterName: 'hrdutycert' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-cert-v-001/hrduty-cert-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrrewards/:hrreward?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrreward.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrrewards', parameterName: 'hrreward' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrreward-edit-view/hrreward-edit-view.vue'),
                },
                {
                    path: 'hrrewards/:hrreward?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrreward.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrrewards', parameterName: 'hrreward' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrreward-edit-view/hrreward-edit-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.hrlegal.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-dashboard-view/hrlegal-dashboard-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrlegal.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-v-001/hrlegal-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrworkrecords/:hrworkrecord?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrworkrecord.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrworkrecords', parameterName: 'hrworkrecord' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrwork-record-grid-view/hrwork-record-grid-view.vue'),
                },
                {
                    path: 'hrworkrecords/:hrworkrecord?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrworkrecord.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrworkrecords', parameterName: 'hrworkrecord' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrwork-record-grid-view/hrwork-record-grid-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyskills/:hrdutyskill?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-grid-view/hrduty-skill-grid-view.vue'),
                },
                {
                    path: 'hrdutyskills/:hrdutyskill?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-grid-view/hrduty-skill-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.hrpost.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-dashboard-view/hrpost-dashboard-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgaddresses/:hrorgaddress?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-edit-view/hrorg-address-edit-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgaddresses/:hrorgaddress?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-edit-view/hrorg-address-edit-view.vue'),
                },
                {
                    path: 'hrorgaddresses/:hrorgaddress?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgaddress.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-address-edit-view/hrorg-address-edit-view.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/hrdutyskills/:hrdutyskill?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-v-001/hrduty-skill-v-001.vue'),
                },
                {
                    path: 'hrdutyskills/:hrdutyskill?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdutyskill.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdutyskills', parameterName: 'hrdutyskill' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-skill-v-001/hrduty-skill-v-001.vue'),
                },
                {
                    path: 'hrduties/:hrduty?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.hrduty.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrduties', parameterName: 'hrduty' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrduty-dashboard-view/hrduty-dashboard-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrfamilies/:hrfamily?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrfamily.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrfamilies', parameterName: 'hrfamily' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrfamily-grid-view/hrfamily-grid-view.vue'),
                },
                {
                    path: 'hrfamilies/:hrfamily?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrfamily.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrfamilies', parameterName: 'hrfamily' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrfamily-grid-view/hrfamily-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrdistributions/:hrdistribution?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-002/hrdistribution-v-002.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrdistributions/:hrdistribution?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-002/hrdistribution-v-002.vue'),
                },
                {
                    path: 'hrdistributions/:hrdistribution?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-002/hrdistribution-v-002.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/hromhierarchies/:hromhierarchy?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-pickup-view/hromhierarchy-pickup-view.vue'),
                },
                {
                    path: 'hromhierarchies/:hromhierarchy?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-pickup-view/hromhierarchy-pickup-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrcertificates/:hrcertificate?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrcertificate.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrcertificates', parameterName: 'hrcertificate' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcertificate-grid-view/hrcertificate-grid-view.vue'),
                },
                {
                    path: 'hrcertificates/:hrcertificate?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrcertificate.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrcertificates', parameterName: 'hrcertificate' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrcertificate-grid-view/hrcertificate-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hrpost.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-tab-exp-view/hrpost-tab-exp-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/tabexpview/:tabexpview?',
                    meta: {
                        caption: 'entities.hrlegal.views.tabexpview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'tabexpview', parameterName: 'tabexpview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrlegal-tab-exp-view/hrlegal-tab-exp-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrtrainingrecords/:hrtrainingrecord?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrtrainingrecord.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrtrainingrecords', parameterName: 'hrtrainingrecord' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtraining-record-grid-view/hrtraining-record-grid-view.vue'),
                },
                {
                    path: 'hrtrainingrecords/:hrtrainingrecord?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrtrainingrecord.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrtrainingrecords', parameterName: 'hrtrainingrecord' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtraining-record-grid-view/hrtraining-record-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hreducations/:hreducation?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.hreducation.views.optionview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hreducations', parameterName: 'hreducation' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hreducation-option-view/hreducation-option-view.vue'),
                },
                {
                    path: 'hreducations/:hreducation?/optionview/:optionview?',
                    meta: {
                        caption: 'entities.hreducation.views.optionview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hreducations', parameterName: 'hreducation' },
                            { pathName: 'optionview', parameterName: 'optionview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hreducation-option-view/hreducation-option-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/dashboardview/:dashboardview?',
                    meta: {
                        caption: 'entities.hroperationunit.views.dashboardview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'dashboardview', parameterName: 'dashboardview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hroperation-unit-dashboard-view/hroperation-unit-dashboard-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrtechnicaltitles/:hrtechnicaltitle?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrtechnicaltitle.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrtechnicaltitles', parameterName: 'hrtechnicaltitle' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtechnical-title-grid-view/hrtechnical-title-grid-view.vue'),
                },
                {
                    path: 'hrtechnicaltitles/:hrtechnicaltitle?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrtechnicaltitle.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrtechnicaltitles', parameterName: 'hrtechnicaltitle' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtechnical-title-grid-view/hrtechnical-title-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrresearches/:hrresearch?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrresearch.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrresearches', parameterName: 'hrresearch' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrresearch-edit-view/hrresearch-edit-view.vue'),
                },
                {
                    path: 'hrresearches/:hrresearch?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrresearch.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrresearches', parameterName: 'hrresearch' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrresearch-edit-view/hrresearch-edit-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/hromhierarchies/:hromhierarchy?/editview/:editview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-edit-view/hromhierarchy-edit-view.vue'),
                },
                {
                    path: 'hromhierarchies/:hromhierarchy?/editview/:editview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-edit-view/hromhierarchy-edit-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrpostrels/:hrpostrel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrpostrel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-grid-view/hrpost-rel-grid-view.vue'),
                },
                {
                    path: 'hrpostrels/:hrpostrel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrpostrel.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrpostrels', parameterName: 'hrpostrel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrpost-rel-grid-view/hrpost-rel-grid-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/editview/:editview?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-edit-view/hromhierarchy-cat-edit-view.vue'),
                },
                {
                    path: 'hroperationunits/:hroperationunit?/hrorgcontacts/:hrorgcontact?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hroperationunits', parameterName: 'hroperationunit' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-edit-view/hrorg-contact-edit-view.vue'),
                },
                {
                    path: 'hrlegals/:hrlegal?/hrorgcontacts/:hrorgcontact?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrlegals', parameterName: 'hrlegal' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-edit-view/hrorg-contact-edit-view.vue'),
                },
                {
                    path: 'hrorgcontacts/:hrorgcontact?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrorgcontact.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrorgcontacts', parameterName: 'hrorgcontact' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hrorg-contact-edit-view/hrorg-contact-edit-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrfamilies/:hrfamily?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrfamily.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrfamilies', parameterName: 'hrfamily' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrfamily-edit-view/hrfamily-edit-view.vue'),
                },
                {
                    path: 'hrfamilies/:hrfamily?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrfamily.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrfamilies', parameterName: 'hrfamily' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrfamily-edit-view/hrfamily-edit-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/v_002/:v_002?',
                    meta: {
                        caption: 'entities.hromhierarchycat.views.v_002.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'v_002', parameterName: 'v_002' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-cat-v-002/hromhierarchy-cat-v-002.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrdistributions/:hrdistribution?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-grid-view/hrdistribution-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrdistributions/:hrdistribution?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-grid-view/hrdistribution-grid-view.vue'),
                },
                {
                    path: 'hrdistributions/:hrdistribution?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.hrdistribution.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-grid-view/hrdistribution-grid-view.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrarchives/:hrarchives?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrarchives.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrarchives', parameterName: 'hrarchives' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrarchives-edit-view/hrarchives-edit-view.vue'),
                },
                {
                    path: 'hrarchives/:hrarchives?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrarchives.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrarchives', parameterName: 'hrarchives' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrarchives-edit-view/hrarchives-edit-view.vue'),
                },
                {
                    path: 'hromhierarchycats/:hromhierarchycat?/hromhierarchies/:hromhierarchy?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchycats', parameterName: 'hromhierarchycat' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-pickup-grid-view/hromhierarchy-pickup-grid-view.vue'),
                },
                {
                    path: 'hromhierarchies/:hromhierarchy?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.hromhierarchy.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hromhierarchies', parameterName: 'hromhierarchy' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/base/hromhierarchy-pickup-grid-view/hromhierarchy-pickup-grid-view.vue'),
                },
                {
                    path: 'hrposts/:hrpost?/hrdistributions/:hrdistribution?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrposts', parameterName: 'hrpost' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-001/hrdistribution-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrdistributions/:hrdistribution?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-001/hrdistribution-v-001.vue'),
                },
                {
                    path: 'hrdistributions/:hrdistribution?/v_001/:v_001?',
                    meta: {
                        caption: 'entities.hrdistribution.views.v_001.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrdistributions', parameterName: 'hrdistribution' },
                            { pathName: 'v_001', parameterName: 'v_001' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrdistribution-v-001/hrdistribution-v-001.vue'),
                },
                {
                    path: 'hremployees/:hremployee?/hrtechnicaltitles/:hrtechnicaltitle?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrtechnicaltitle.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hremployees', parameterName: 'hremployee' },
                            { pathName: 'hrtechnicaltitles', parameterName: 'hrtechnicaltitle' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtechnical-title-edit-view/hrtechnical-title-edit-view.vue'),
                },
                {
                    path: 'hrtechnicaltitles/:hrtechnicaltitle?/editview/:editview?',
                    meta: {
                        caption: 'entities.hrtechnicaltitle.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'pim', parameterName: 'pim' },
                            { pathName: 'hrtechnicaltitles', parameterName: 'hrtechnicaltitle' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/human-resource/hrtechnical-title-edit-view/hrtechnical-title-edit-view.vue'),
                },
            ...indexRoutes,
            ],
        },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                appService.navHistory.reset();
                next();
            },
            component: () => import('@components/login/login'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'pim'
        }
    ]
});

router.beforeEach((to: any, from: any, next: any) => {
    if (to.meta && !to.meta.ignoreAddPage) {
        appService.navHistory.add(to);
    }
    next();
});

export default router;